==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_aimodelCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_aimodel;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aibdatasetscontainerRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aiconfigurationRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aimodelRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class Msdyn_aimodelCollectionRequest extends CollectionPageEntityRequest<Msdyn_aimodel, Msdyn_aimodelRequest>{

    protected ContextPath contextPath;

    public Msdyn_aimodelCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_aimodel.class, cp -> new Msdyn_aimodelRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_aimodel_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_aimodel_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_aimodel_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_aimodel_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_aimodel_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_aimodel_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_aimodel_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_aimodel_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_aimodel_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_aimodel_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_aimodel_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_aimodel_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_aimodel_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_aimodel_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_aimodel_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_aimodel_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_aimodel_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_aimodel_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_aimodel_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_aimodel_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_aimodel_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_aimodel_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_aimodel_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_aimodel_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest msdyn_aimodel_Annotations() {
        return new AnnotationCollectionRequest(contextPath.addSegment("msdyn_aimodel_Annotations"), Optional.empty());
    }

    public AnnotationRequest msdyn_aimodel_Annotations(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("msdyn_aimodel_Annotations").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public Msdyn_aiconfigurationCollectionRequest msdyn_aimodel_msdyn_aiconfiguration() {
        return new Msdyn_aiconfigurationCollectionRequest(contextPath.addSegment("msdyn_aimodel_msdyn_aiconfiguration"), Optional.empty());
    }

    public Msdyn_aiconfigurationRequest msdyn_aimodel_msdyn_aiconfiguration(String msdyn_aiconfigurationid) {
        return new Msdyn_aiconfigurationRequest(contextPath.addSegment("msdyn_aimodel_msdyn_aiconfiguration").addKeys(new NameValue(msdyn_aiconfigurationid.toString())), Optional.empty());
    }

    public Msdyn_aibdatasetscontainerCollectionRequest msdyn_AIBDatasetsContainer_msdyn_AIModelI() {
        return new Msdyn_aibdatasetscontainerCollectionRequest(contextPath.addSegment("msdyn_AIBDatasetsContainer_msdyn_AIModelI"), Optional.empty());
    }

    public Msdyn_aibdatasetscontainerRequest msdyn_AIBDatasetsContainer_msdyn_AIModelI(String msdyn_aibdatasetscontainerid) {
        return new Msdyn_aibdatasetscontainerRequest(contextPath.addSegment("msdyn_AIBDatasetsContainer_msdyn_AIModelI").addKeys(new NameValue(msdyn_aibdatasetscontainerid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_aimodelCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_aimodel;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aibdatasetscontainerRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aiconfigurationRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aimodelRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class Msdyn_aimodelCollectionRequest extends CollectionPageEntityRequest<Msdyn_aimodel, Msdyn_aimodelRequest>{

    protected ContextPath contextPath;

    public Msdyn_aimodelCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_aimodel.class, cp -> new Msdyn_aimodelRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_aimodel_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_aimodel_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_aimodel_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_aimodel_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_aimodel_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_aimodel_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_aimodel_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_aimodel_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_aimodel_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_aimodel_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_aimodel_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_aimodel_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_aimodel_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_aimodel_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_aimodel_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_aimodel_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_aimodel_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_aimodel_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_aimodel_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_aimodel_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_aimodel_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_aimodel_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_aimodel_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_aimodel_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest msdyn_aimodel_Annotations() {
        return new AnnotationCollectionRequest(contextPath.addSegment("msdyn_aimodel_Annotations"), Optional.empty());
    }

    public AnnotationRequest msdyn_aimodel_Annotations(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("msdyn_aimodel_Annotations").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public Msdyn_aiconfigurationCollectionRequest msdyn_aimodel_msdyn_aiconfiguration() {
        return new Msdyn_aiconfigurationCollectionRequest(contextPath.addSegment("msdyn_aimodel_msdyn_aiconfiguration"), Optional.empty());
    }

    public Msdyn_aiconfigurationRequest msdyn_aimodel_msdyn_aiconfiguration(String msdyn_aiconfigurationid) {
        return new Msdyn_aiconfigurationRequest(contextPath.addSegment("msdyn_aimodel_msdyn_aiconfiguration").addKeys(new NameValue(msdyn_aiconfigurationid.toString())), Optional.empty());
    }

    public Msdyn_aibdatasetscontainerCollectionRequest msdyn_AIBDatasetsContainer_msdyn_AIModelI() {
        return new Msdyn_aibdatasetscontainerCollectionRequest(contextPath.addSegment("msdyn_AIBDatasetsContainer_msdyn_AIModelI"), Optional.empty());
    }

    public Msdyn_aibdatasetscontainerRequest msdyn_AIBDatasetsContainer_msdyn_AIModelI(String msdyn_aibdatasetscontainerid) {
        return new Msdyn_aibdatasetscontainerRequest(contextPath.addSegment("msdyn_AIBDatasetsContainer_msdyn_AIModelI").addKeys(new NameValue(msdyn_aibdatasetscontainerid.toString())), Optional.empty());
    }

}
